/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * Diese Klasse nutzt den {@link de.bsvrz.sys.funclib.bitctrl.interpreter
 * Interpreter} um mehrere Variablen gleichzeitig zu fuzzyfizieren.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public class Fuzzyfizierung implements Ausdruck {

	/** Menge der zu fuzzyfizierenden Basisvariablen. */
	private final Map<String, String> basisvariablen;

	/**
	 * Initialisierung.
	 */
	public Fuzzyfizierung() {
		basisvariablen = new HashMap<>();
	}

	/**
	 * F&uuml;gt eine zu fuzzyfizierende Variable der Menge hinzu.
	 *
	 * @param name
	 *            Name der zu fuzzyfizierenden Basisvariable
	 * @param lv
	 *            Name der linguistischen Variable (enth&auml;lt die notwendigen
	 *            Fuzzy-Sets)
	 */
	public void addBasisvariable(final String name, final String lv) {
		basisvariablen.put(name, lv);
	}

	/**
	 * Gibt immer {@code null} zur&uuml;ck, da dies ein Terminalsymbol ist.
	 * <p>
	 * {@inheritDoc}
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		return null;
	}

	/**
	 * Gibt eine Liste von fuzzyfizierten Werten zur&uuml;ck. Die
	 * Fuzzy-Variablen erhalten den Namen der Basisvariable.
	 *
	 * {@inheritDoc}
	 */
	@Override
	public List<FuzzyVariable> interpret(final Kontext kontext) {
		final List<FuzzyVariable> ergebnis = new ArrayList<>();

		for (final String name : basisvariablen.keySet()) {
			final LinguistischeVariable lv = (LinguistischeVariable) kontext
					.get(basisvariablen.get(name), LinguistischeVariable.class);
			final FuzzyVariable fv = lv
					.fuzzyfiziere((Integer) kontext.get(name, Integer.class));
			fv.setName(name);
			ergebnis.add(fv);
		}

		return ergebnis;
	}

}
